@@ -21,13 +21,10 @@
 
 #include "about.h"
 
-//qdaccolib
-#include <auxiliar.h>
-
 About::About(QWidget *)  //parent
 {
 	ui.setupUi(this);
-	ui.versio->setText(tr("qdacco version: ")+Auxiliar::getVersion());
-	ui.name->setText("Carles Pina i Estany, "+Auxiliar::getCopyrightDate());
+	ui.versio->setText(tr("qdacco version: ")+AuxiliarGUI::getVersion());
+	ui.name->setText("Carles Pina i Estany, "+AuxiliarGUI::getCopyrightDate());
 }
 
