@@ -21,9 +21,17 @@
 
 #include "main.h"
 
+void Main::primerPla() {
+	printf("MAIN: POSAR-LO EN PRIMER PLA\n");
+	/*TrayIcon *trayicon;
+	trayicon = TrayIcon::instance();
+
+	trayicon->primerPla();
+	*/
+}
+
 Main::Main(QWidget *)  //parent
 {
-
         ui.setupUi(this);
 	ui.paraula->setParent(this);
 	ui.llistat->setParent(this);
@@ -32,6 +40,11 @@ Main::Main(QWidget *)  //parent
 
 	resize(QSize(270,300));
 
+	/*TrayIcon *trayicon;
+	trayicon = TrayIcon::instance();
+	trayicon->SetMain(this);
+	*/
+
 	
 	ui.report->setEnabled(false);
 
@@ -276,6 +289,16 @@ void Main::buscarEnter()
 	buscar();
 }
 
+QString Main::getParaula()
+{
+	return ui.paraula->text();
+}
+
+void Main::setParaula(QString paraula)
+{
+	ui.paraula->setText(paraula);
+}
+
 void Main::buscar()
 {
 	treballaBuscar();
@@ -398,6 +421,14 @@ void Main::UpdateList() {
 	}
 }
 
+int Main::getIdiomaActiu() {
+	return m_idioma_actiu;
+}
+
+void Main::setIdiomaActiu(int actiu) {
+	m_idioma_actiu = actiu;
+	posa_idioma();
+}
 
 void Main::treballaBuscar() {
         StructureParser handler;
@@ -592,7 +623,7 @@ void Main::carrega_config(int )
 
 	version = qs.value("/dacco/version","0").toString();
 
-        if (version!="0.7") { //TODO: change to program constant
+        if (version!="0.8") { //TODO: change to program constant
                 //We will open the same settings file with read and then write mode
                 //be careful!
                 QMessageBox::information( this, "qdacco",tr("There is no configuration or old configuration. A configuration dialog will now open"));
@@ -766,6 +797,20 @@ void Main::showMessage(QString text) {
 	ui.actiu->show();
 }
 
+void Main::restaura() {
+	printf("Restaurant...\n");
+	setWindowState(windowState() & ~Qt::WindowMinimized | Qt::WindowActive);
+	this->show();
+	this->setFocus(Qt::ShortcutFocusReason);
+	this->show();
+}
+
+void Main::quit() {
+	printf("Quitting...\n");
+	exit(0);
+}
+
+
 /*
 void AuxiliarGUI::setMain(void *_m) {
 	AuxiliarGUI::m = _m;
