@@ -19,14 +19,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef MYLISTWIDGET_H
 #define MYLISTWIDGET_H
 
 #include <QtGui>
 
 //qdaccolib
-#include <auxiliar.h>
+#include <qdacco/auxiliar.h>
 
 class MyListWidget: public QListWidget
 {
